==> kubernetes-model-core-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/AffinityBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AffinityBuilder extends io.fabric8.kubernetes.api.model.AffinityFluentImpl<io.fabric8.kubernetes.api.model.AffinityBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.Affinity,io.fabric8.kubernetes.api.model.AffinityBuilder>{
  public AffinityBuilder() {
    this(false);
  }
  public AffinityBuilder(java.lang.Boolean validationEnabled) {
    this(new Affinity(), validationEnabled);
  }
  public AffinityBuilder(io.fabric8.kubernetes.api.model.AffinityFluent<?> fluent) {
    this(fluent, false);
  }
  public AffinityBuilder(io.fabric8.kubernetes.api.model.AffinityFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Affinity(), validationEnabled);
  }
  public AffinityBuilder(io.fabric8.kubernetes.api.model.AffinityFluent<?> fluent,io.fabric8.kubernetes.api.model.Affinity instance) {
    this(fluent, instance, false);
  }
  public AffinityBuilder(io.fabric8.kubernetes.api.model.AffinityFluent<?> fluent,io.fabric8.kubernetes.api.model.Affinity instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withNodeAffinity(instance.getNodeAffinity()); 
    fluent.withPodAffinity(instance.getPodAffinity()); 
    fluent.withPodAntiAffinity(instance.getPodAntiAffinity()); 
    this.validationEnabled = validationEnabled; 
  }
  public AffinityBuilder(io.fabric8.kubernetes.api.model.Affinity instance) {
    this(instance,false);
  }
  public AffinityBuilder(io.fabric8.kubernetes.api.model.Affinity instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withNodeAffinity(instance.getNodeAffinity()); 
    this.withPodAffinity(instance.getPodAffinity()); 
    this.withPodAntiAffinity(instance.getPodAntiAffinity()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.AffinityFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.Affinity build() {
    Affinity buildable = new Affinity(fluent.getNodeAffinity(),fluent.getPodAffinity(),fluent.getPodAntiAffinity());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AffinityBuilder that = (AffinityBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/AffinityBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AffinityBuilder extends io.fabric8.kubernetes.api.model.AffinityFluentImpl<io.fabric8.kubernetes.api.model.AffinityBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.Affinity,io.fabric8.kubernetes.api.model.AffinityBuilder>{
  public AffinityBuilder() {
    this(false);
  }
  public AffinityBuilder(java.lang.Boolean validationEnabled) {
    this(new Affinity(), validationEnabled);
  }
  public AffinityBuilder(io.fabric8.kubernetes.api.model.AffinityFluent<?> fluent) {
    this(fluent, false);
  }
  public AffinityBuilder(io.fabric8.kubernetes.api.model.AffinityFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Affinity(), validationEnabled);
  }
  public AffinityBuilder(io.fabric8.kubernetes.api.model.AffinityFluent<?> fluent,io.fabric8.kubernetes.api.model.Affinity instance) {
    this(fluent, instance, false);
  }
  public AffinityBuilder(io.fabric8.kubernetes.api.model.AffinityFluent<?> fluent,io.fabric8.kubernetes.api.model.Affinity instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withNodeAffinity(instance.getNodeAffinity()); 
    fluent.withPodAffinity(instance.getPodAffinity()); 
    fluent.withPodAntiAffinity(instance.getPodAntiAffinity()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public AffinityBuilder(io.fabric8.kubernetes.api.model.Affinity instance) {
    this(instance,false);
  }
  public AffinityBuilder(io.fabric8.kubernetes.api.model.Affinity instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withNodeAffinity(instance.getNodeAffinity()); 
    this.withPodAffinity(instance.getPodAffinity()); 
    this.withPodAntiAffinity(instance.getPodAntiAffinity()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.AffinityFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.Affinity build() {
    Affinity buildable = new Affinity(fluent.getNodeAffinity(),fluent.getPodAffinity(),fluent.getPodAntiAffinity());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AffinityBuilder that = (AffinityBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
